# axreldable

axreldable's python utils

## Installation

```bash
pip install git+https://github.com/axreldable/axreldable_python_lib.git
```

## Usage

```python
from axreldable.printing import print_list

if __name__ == "__main__":
    print_list([1, 2, 3])
```
